import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  area,
  curveBasis
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = (data) => {
  const title = 'A Week in San Francisco';
  const xValue = (d) => d.timestamp;
  const xAxisLabel = 'Time';

  const yValue = (d) => d.temperature;
  const yAxisLabel = 'Temperature';
  const circleRadius = 6;
  const margin = {
    top: 60,
    right: 40,
    bottom: 88,
    left: 110,
  };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    // .nice();

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();

  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`
    );


  const xAxis = axisBottom(xScale)
  	.ticks(6)
    .tickSize(-innerHeight)
    .tickPadding(15);

  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);

  const yAxisG = g.append('g').call(yAxis);

  yAxisG.selectAll('.domain').remove();

  yAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('x', -innerHeight / 2)
    .attr('y', -70)
    .attr('fill', 'black')
    .attr('transform', `rotate(-90)`)
    .attr('text-anchor', 'middle')
    .text(yAxisLabel);

  const xAxisG = g
    .append('g')
    .call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);

  xAxisG.select('.domain').remove();

  xAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('x', 200)
    .text(xAxisLabel)
    .attr('fill', 'black')
    .attr('x', innerWidth / 2)
    .attr('y', 75);
  
  const areaGenerator = area()
  	.x((d) => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1((d) => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class','line-path')
  	.attr('d', areaGenerator(data))

  g.append('text')
    .attr('y', -10)
    .attr('class', 'title')
    .text(title);
};

csv('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv').then(
  (data) => {
    console.log(data);
    data.forEach((d) => {
      d.temperature = +d.temperature;
      d.timestamp = new Date(d.timestamp);
    });
    render(data);
  }
);
